@@ -1,35 +1,21 @@
-/*
-    Copyright (C) 2019 Nicolas Fella <nicolas.fella@gmx.de>
+// SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
 #include "callhistorymodel.h"
 
-#include <QDateTime>
-#include <QStandardPaths>
-#include <QSqlQuery>
-#include <QSqlError>
-#include <QDebug>
 #include <KPeople/PersonData>
+#include <QDateTime>
+#include <QDebug>
+#include <QSqlError>
+#include <QSqlQuery>
+#include <QStandardPaths>
+
+#include "contactmapper.h"
 
 CallHistoryModel::CallHistoryModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_database(this)
-    , m_mapper(new ContactMapper(this))
 {
-    m_mapper.performInitialScan();
-
     beginResetModel();
     m_calls = m_database.fetchCalls();
     endResetModel();
@@ -59,25 +45,25 @@ void CallHistoryModel::clear()
     endResetModel();
 }
 
-QVariant CallHistoryModel::data(const QModelIndex& index, int role) const
+QVariant CallHistoryModel::data(const QModelIndex &index, int role) const
 {
     int row = index.row();
 
     switch (role) {
-        case Roles::PhoneNumberRole:
-            return m_calls[row].number;
-        case DisplayNameRole:
-            return KPeople::PersonData{m_mapper.uriForNumber(m_calls.at(index.row()).number)}.name();
-        case PhotoRole:
-            return KPeople::PersonData{m_mapper.uriForNumber(m_calls.at(index.row()).number)}.photo();
-        case Roles::CallTypeRole:
-            return m_calls[row].callType;
-        case Roles::DurationRole:
-            return m_calls[row].duration;
-        case Roles::TimeRole:
-            return m_calls[row].time;
-        case Roles::IdRole:
-            return m_calls[row].id;
+    case Roles::PhoneNumberRole:
+        return m_calls[row].number;
+    case DisplayNameRole:
+        return KPeople::PersonData{ContactMapper::instance().uriForNumber(m_calls.at(index.row()).number)}.name();
+    case PhotoRole:
+        return KPeople::PersonData{ContactMapper::instance().uriForNumber(m_calls.at(index.row()).number)}.photo();
+    case Roles::CallTypeRole:
+        return m_calls[row].callType;
+    case Roles::DurationRole:
+        return m_calls[row].duration;
+    case Roles::TimeRole:
+        return m_calls[row].time;
+    case Roles::IdRole:
+        return m_calls[row].id;
     }
     return {};
 }
