@@ -1,35 +1,20 @@
-/*
-    Copyright (C) 2019 Nicolas Fella <nicolas.fella@gmx.de>
+// SPDX-FileCopyrightText: 2019 Nicolas Fella <nicolas.fella@gmx.de>
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
 #pragma once
 
 #include <QAbstractListModel>
-#include <QSortFilterProxyModel>
 #include <QDateTime>
+#include <QSortFilterProxyModel>
 #include <QVector>
 
-#include "dialerutils.h"
 #include "database.h"
-#include "contactmapper.h"
+#include "dialerutils.h"
 
 class CallHistoryModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
-
     CallHistoryModel(QObject *parent = nullptr);
 
     enum Roles {
@@ -39,7 +24,7 @@ public:
         DurationRole,
         TimeRole,
         CallTypeRole,
-        IdRole
+        IdRole,
     };
     Q_ENUM(Roles)
 
@@ -56,5 +41,4 @@ public:
 private:
     QVector<CallData> m_calls;
     Database m_database;
-    ContactMapper m_mapper;
 };
