@@ -1,19 +1,7 @@
 /*
- * Copyright 2015 Marco Martin <mart@kde.org>
+ * SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
-
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
-
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
 **/
 
 #ifndef DIALERUTILS_H
@@ -21,7 +9,6 @@
 
 #include <QObject>
 #include <QPointer>
-#include <KNotification>
 
 #include <TelepathyQt/Account>
 #include <qofono-qt5/qofonomessagewaiting.h>
@@ -34,6 +21,8 @@ class DialerUtils : public QObject
     Q_PROPERTY(QString callContactAlias READ callContactAlias NOTIFY callContactAliasChanged);
     Q_PROPERTY(QString callContactNumber READ callContactNumber NOTIFY callContactNumberChanged);
     Q_PROPERTY(bool isIncomingCall READ isIncomingCall NOTIFY isIncomingCallChanged);
+    Q_PROPERTY(QString callContactDisplayString READ callContactDisplayString NOTIFY callContactDisplayStringChanged);
+    Q_PROPERTY(QPixmap callContactPicture READ callContactPicture NOTIFY callContactPictureChanged);
 
 public:
     enum CallState {
@@ -43,14 +32,14 @@ public:
         Answered,
         Active,
         Ended,
-        Failed
+        Failed,
     };
     Q_ENUM(CallState)
 
     enum CallType {
         IncomingRejected,
         IncomingAccepted,
-        Outgoing
+        Outgoing,
     };
     Q_ENUM(CallType)
 
@@ -74,9 +63,13 @@ public:
 
     void emitCallEnded();
 
+    QString callContactDisplayString() const;
+
+    QPixmap callContactPicture() const;
+
     Q_INVOKABLE void resetMissedCalls();
     Q_INVOKABLE void dial(const QString &number);
-    Q_INVOKABLE QString formatNumber(const QString& number);
+    Q_INVOKABLE QString formatNumber(const QString &number);
     Q_INVOKABLE void getImeis();
     Q_INVOKABLE QString getVoicemailNumber();
 
@@ -87,11 +80,15 @@ Q_SIGNALS:
     void callContactAliasChanged();
     void callContactNumberChanged();
     void isIncomingCallChanged();
+    void callContactDisplayStringChanged();
+    void callContactPictureChanged();
     void acceptCall();
     void rejectCall();
     void hangUp();
     void callEnded(const QString &callContactNumber, uint callDuration, bool isIncomingCall);
     void sendDtmf(const QString &tones);
+    void setSpeakerMode(bool enabled);
+    void setMute(bool muted);
     void initiateUssd(const QString &command);
     void respondToUssd(const QString &reply);
     void cancelUssd();
@@ -100,16 +97,14 @@ Q_SIGNALS:
     void displayImeis(const QStringList &imeis);
 
 private:
-    QPointer <KNotification> m_callsNotification;
-    QPointer <KNotification> m_ringingNotification;
-    int m_missedCalls;
-    CallState m_callState;
+    int m_missedCalls = 0;
+    CallState m_callState = CallState::Idle;
     Tp::AccountPtr m_simAccount;
     QString m_callContactNumber;
-    uint m_callDuration;
+    uint m_callDuration = 0;
     QString m_callContactAlias;
     bool m_isIncomingCall;
-    QOfonoMessageWaiting* m_msgWaiting;
+    QOfonoMessageWaiting *m_msgWaiting = nullptr;
     QString m_voicemailNumber;
 };
 
